[![PyPI - Version](https://img.shields.io/pypi/v/pcg_skel)](https://pypi.org/project/pcg-skel/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7703278.svg)](https://doi.org/10.5281/zenodo.7703278)

# pcg_skel

Generate robust neuronal topology directly from PyChunkedGraph dynamic segmentations. Skeletonization is an essential part of measuring neuronal anatomy, but in 3d segmented data it is not always trivial to produce a skeleton.

## Documentation

You can find documentation [on our GitHub pages](https://caveconnectome.github.io/pcg_skel/)
